@@ -78,7 +78,7 @@ class VideoCaptureImages:
 	def get_batch(self, idx_inicial, batch_size = 8):
 		images = []
 		i = 0
-		past_img = np.full((*img_obj.img_shape,3), 255)
+		past_img = np.full((*self.img_shape,3), 255)
 		while i<batch_size:
 			state, img = self.vidcap.read()
 			self.actual_vidcap_count+=1
@@ -87,7 +87,7 @@ class VideoCaptureImages:
 					img = img if not (img is None) else past_img
 					if not (img is None):
 						images.append(img)
-					past_img=np.full((*img_obj.img_shape,3), 255)
+					past_img=np.full((*self.img_shape,3), 255)
 					i+=1
 				elif not (img is None):
 					past_img = img.copy()
